==> haskell-reflection-2.1.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.2
id: reflection-2.1.2-HPYmHAmlpRJ9gRQTzfKOSy
key: reflection-2.1.2-HPYmHAmlpRJ9gRQTzfKOSy
license: BSD3
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
exposed: True
indefinite: False
exposed-modules:
    Data.Reflection
abi: a2c942b5f5621900f149e66cf4940734
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/reflection-2.1.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/reflection-2.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/reflection-2.1.2
hs-libraries: HSreflection-2.1.2-HPYmHAmlpRJ9gRQTzfKOSy
depends:
    base-4.10.0.0 template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reflection-2.1.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.2
id: reflection-2.1.2-C2CXGjPrlDWEm9x409Gv1U
key: reflection-2.1.2-C2CXGjPrlDWEm9x409Gv1U
license: BSD3
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
exposed: True
indefinite: False
exposed-modules:
    Data.Reflection
abi: 660955b15b9b2e723ad9368b50863425
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/reflection-2.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/reflection-2.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/reflection-2.1.2
hs-libraries: HSreflection-2.1.2-C2CXGjPrlDWEm9x409Gv1U
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
